@@ -26,7 +26,7 @@
 #include <goffice/graph/gog-3d-box.h>
 #include <goffice/graph/gog-plot-impl.h>
 #include <goffice/graph/gog-graph-impl.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-axis-line-impl.h>
@@ -35,17 +35,19 @@
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/math/go-math.h>
 #include <goffice/math/go-matrix3x3.h>
+#include <goffice/utils/go-persist.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include <math.h>
 
+#ifdef GOFFICE_WITH_LASEM
+#include <goffice/graph/gog-equation.h>
+#endif
+
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
 #endif
 
 static const struct {
@@ -184,7 +186,7 @@ gog_chart_get_property (GObject *obj, guint param_id,
 
 static void
 gog_chart_populate_editor (GogObject *gobj, 
-			   GogEditor *editor, 
+			   GOEditor *editor, 
 			   G_GNUC_UNUSED GogDataAllocator *dalloc, 
 			   GOCmdContext *cc)
 {
@@ -192,7 +194,7 @@ gog_chart_populate_editor (GogObject *gobj,
 
 	(GOG_OBJECT_CLASS(chart_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	gog_editor_set_store_page (editor, &chart_pref_page);
+	go_editor_set_store_page (editor, &chart_pref_page);
 }
 
 static void
@@ -202,7 +204,7 @@ gog_chart_children_reordered (GogObject *obj)
 	GogChart *chart = GOG_CHART (obj);
 
 	for (ptr = obj->children; ptr != NULL ; ptr = ptr->next)
-		if (IS_GOG_PLOT (ptr->data))
+		if (GOG_IS_PLOT (ptr->data))
 			accum = g_slist_prepend (accum, ptr->data);
 	g_slist_free (chart->plots);
 	chart->plots = g_slist_reverse (accum);
@@ -210,6 +212,13 @@ gog_chart_children_reordered (GogObject *obj)
 	gog_chart_request_cardinality_update (chart);
 }
 
+static gboolean
+role_plot_can_add (GogObject *parent, GogObject *child)
+{
+	GogChart *chart = GOG_CHART (parent);
+	return (chart->axis_set & (1 << GOG_AXIS_Z)) == 0 || g_slist_length (chart->plots) == 0;
+}
+
 static void
 role_plot_post_add (GogObject *parent, GogObject *plot)
 {
@@ -222,7 +231,7 @@ role_plot_post_add (GogObject *parent, GogObject *plot)
 		int i = GOG_AXIS_VIRTUAL, j = 1 << GOG_AXIS_VIRTUAL;
 		for (; i < GOG_AXIS_TYPES; i++, j <<= 1)
 			if ((axis_set & j) != 0 && (chart->axis_set & j) == 0) {
-				GogObject *axis = GOG_OBJECT (g_object_new (GOG_AXIS_TYPE, "type", i, NULL));
+				GogObject *axis = GOG_OBJECT (g_object_new (GOG_TYPE_AXIS, "type", i, NULL));
 				chart->axis_set |= j;
 				switch (i) {
 				case GOG_AXIS_PSEUDO_3D:
@@ -304,11 +313,46 @@ role_grid_pre_remove (GogObject *parent, GogObject *grid)
 	chart->grid = NULL;
 }
 
+static gboolean
+xy_grid_3d_can_add (GogObject const *parent)
+{
+	return (GOG_CHART (parent)->axis_set == GOG_AXIS_SET_XYZ &&
+		NULL == gog_object_get_child_by_name (parent, "XY-Backplane"));
+}
+
+static gboolean
+yz_grid_3d_can_add (GogObject const *parent)
+{
+	return (GOG_CHART (parent)->axis_set == GOG_AXIS_SET_XYZ &&
+		NULL == gog_object_get_child_by_name (parent, "YZ-Backplane"));
+}
+
+static gboolean
+zx_grid_3d_can_add (GogObject const *parent)
+{
+	return (GOG_CHART (parent)->axis_set == GOG_AXIS_SET_XYZ &&
+		NULL == gog_object_get_child_by_name (parent, "ZX-Backplane"));
+}
+
+static void
+grid_3d_post_add (GogObject *child, GogGridType t)
+{
+	g_object_set (G_OBJECT (child), "type", (int)t, NULL);
+}
+
+static void xy_grid_3d_post_add    (GogObject *parent, GogObject *child)
+{ grid_3d_post_add (child, GOG_GRID_XY); }
+static void yz_grid_3d_post_add    (GogObject *parent, GogObject *child)
+{ grid_3d_post_add (child, GOG_GRID_YZ); }
+static void zx_grid_3d_post_add    (GogObject *parent, GogObject *child)
+{ grid_3d_post_add (child, GOG_GRID_ZX); }
+
 static gboolean
 axis_can_add (GogObject const *parent, GogAxisType t)
 {
 	GogChart *chart = GOG_CHART (parent);
-	if (chart->axis_set == GOG_AXIS_SET_UNKNOWN)
+	if (chart->axis_set == GOG_AXIS_SET_UNKNOWN
+	    || chart->axis_set == GOG_AXIS_SET_XYZ)
 		return FALSE;
 	return (chart->axis_set & (1 << t)) != 0;
 }
@@ -360,6 +404,18 @@ static GogObjectRole const roles[] = {
 	{ N_("Backplane"), "GogGrid",	0,
 	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
 	  role_grid_can_add, NULL, NULL, role_grid_post_add, role_grid_pre_remove, NULL, { -1 } },
+	{ N_("XY-Backplane"), "GogGrid",	0,
+	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
+	  xy_grid_3d_can_add, NULL, NULL, xy_grid_3d_post_add, NULL, NULL,
+	  { GOG_GRID_XY } },
+	{ N_("YZ-Backplane"), "GogGrid",	0,
+	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
+	  yz_grid_3d_can_add, NULL, NULL, yz_grid_3d_post_add, NULL, NULL,
+	  { GOG_GRID_YZ } },
+	{ N_("ZX-Backplane"), "GogGrid",	0,
+	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
+	  zx_grid_3d_can_add, NULL, NULL, zx_grid_3d_post_add, NULL, NULL,
+	  { GOG_GRID_ZX } },
 	{ N_("X-Axis"), "GogAxis",	1,
 	  GOG_POSITION_PADDING, GOG_POSITION_PADDING, GOG_OBJECT_NAME_BY_ROLE,
 	  x_axis_can_add, axis_can_remove, NULL, x_axis_post_add, axis_pre_remove, NULL,
@@ -394,7 +450,7 @@ static GogObjectRole const roles[] = {
 	  { GOG_AXIS_COLOR } },
 	{ N_("Plot"), "GogPlot",	6,	/* keep the axis before the plots */
 	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_TYPE,
-	  NULL, NULL, NULL, role_plot_post_add, role_plot_pre_remove, NULL, { -1 } },
+	  role_plot_can_add, NULL, NULL, role_plot_post_add, role_plot_pre_remove, NULL, { -1 } },
 	{ N_("Title"), "GogLabel",	10,
 	  GOG_POSITION_COMPASS|GOG_POSITION_ANY_MANUAL, 
 	  GOG_POSITION_N|GOG_POSITION_ALIGN_CENTER, 
@@ -405,6 +461,13 @@ static GogObjectRole const roles[] = {
 	  GOG_POSITION_E|GOG_POSITION_ALIGN_CENTER, 
 	  GOG_OBJECT_NAME_BY_ROLE,
 	  NULL, NULL, NULL, NULL, NULL, NULL, { -1 } },
+#ifdef GOFFICE_WITH_LASEM
+	{ N_("Equation"), "GogEquation",	11,
+	  GOG_POSITION_COMPASS|GOG_POSITION_ANY_MANUAL,
+	  GOG_POSITION_S|GOG_POSITION_ALIGN_CENTER,
+	  GOG_OBJECT_NAME_BY_ROLE,
+	  NULL, NULL, NULL, NULL, NULL, NULL, { -1 } },
+#endif
 	{ N_("3D-Box"), "Gog3DBox",	0,
 	  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
 	  role_3d_box_can_add, role_3d_box_can_remove, NULL, NULL, NULL, NULL, { -1 } }
@@ -435,13 +498,13 @@ gog_chart_class_init (GogObjectClass *gog_klass)
 				     _("Plot area"),
 				     _("Position and size of plot area, in percentage of chart size"),
 				     "0 0 1 1", 
-				     GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+				     GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, CHART_PROP_PLOT_AREA_IS_MANUAL,
 		g_param_spec_boolean ("is-plot-area-manual", 
 				      _("Manual plot area"), 
 				      _("Is plot area manual"),
 				      FALSE, 
-				      GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+				      GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_klass->view_type = gog_chart_view_get_type ();
 	gog_klass->update    = gog_chart_update;
@@ -470,7 +533,7 @@ gog_chart_init (GogChart *chart)
 
 GSF_CLASS (GogChart, gog_chart,
 	   gog_chart_class_init, gog_chart_init,
-	   GOG_OUTLINED_OBJECT_TYPE)
+	   GOG_TYPE_OUTLINED_OBJECT)
 
 /**
  * gog_chart_get_position :
@@ -512,7 +575,7 @@ void
 gog_chart_set_position (GogChart *chart,
 			unsigned int x, unsigned int y, unsigned int cols, unsigned int rows)
 {
-	g_return_if_fail (IS_GOG_CHART (chart));
+	g_return_if_fail (GOG_IS_CHART (chart));
 
 	if (chart->x == x && chart->y == y &&
 	    chart->cols == cols && chart->rows == rows)
@@ -585,7 +648,7 @@ gog_chart_get_cardinality (GogChart *chart, unsigned *full, unsigned *visible)
 	GSList *ptr;
 	unsigned tmp_full, tmp_visible;
 
-	g_return_if_fail (IS_GOG_CHART (chart));
+	g_return_if_fail (GOG_IS_CHART (chart));
 
 	if (!chart->cardinality_valid) {
 		chart->cardinality_valid = TRUE;
@@ -607,7 +670,7 @@ gog_chart_get_cardinality (GogChart *chart, unsigned *full, unsigned *visible)
 void
 gog_chart_request_cardinality_update (GogChart *chart)
 {
-	g_return_if_fail (IS_GOG_CHART (chart));
+	g_return_if_fail (GOG_IS_CHART (chart));
 	
 	if (chart->cardinality_valid) {
 		chart->cardinality_valid = FALSE;
@@ -621,7 +684,7 @@ gog_chart_foreach_elem (GogChart *chart, gboolean only_visible,
 {
 	GSList *ptr;
 
-	g_return_if_fail (IS_GOG_CHART (chart));
+	g_return_if_fail (GOG_IS_CHART (chart));
 	g_return_if_fail (chart->cardinality_valid);
 
 	for (ptr = chart->plots ; ptr != NULL ; ptr = ptr->next)
@@ -631,14 +694,14 @@ gog_chart_foreach_elem (GogChart *chart, gboolean only_visible,
 GSList *
 gog_chart_get_plots (GogChart const *chart)
 {
-	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	g_return_val_if_fail (GOG_IS_CHART (chart), NULL);
 	return chart->plots;
 }
 
 GogAxisSet
 gog_chart_get_axis_set (GogChart const *chart)
 {
-	g_return_val_if_fail (IS_GOG_CHART (chart), GOG_AXIS_SET_UNKNOWN);
+	g_return_val_if_fail (GOG_IS_CHART (chart), GOG_AXIS_SET_UNKNOWN);
 	return chart->axis_set;
 }
 
@@ -647,7 +710,7 @@ gog_chart_axis_set_is_valid (GogChart const *chart, GogAxisSet type)
 {
 	GSList *ptr;
 
-	g_return_val_if_fail (IS_GOG_CHART (chart), FALSE);
+	g_return_val_if_fail (GOG_IS_CHART (chart), FALSE);
 
 	for (ptr = chart->plots ; ptr != NULL ; ptr = ptr->next)
 		if (!gog_plot_axis_set_is_valid (ptr->data, type))
@@ -674,7 +737,7 @@ gog_chart_axis_set_assign (GogChart *chart, GogAxisSet axis_set)
 	GSList  *ptr;
 	GogAxisType type;
 
-	g_return_val_if_fail (IS_GOG_CHART (chart), FALSE);
+	g_return_val_if_fail (GOG_IS_CHART (chart), FALSE);
 
 	if (chart->axis_set == axis_set)
 		return TRUE;
@@ -702,7 +765,7 @@ gog_chart_axis_set_assign (GogChart *chart, GogAxisSet axis_set)
 	for (ptr = GOG_OBJECT (chart)->children ; ptr != NULL ; ) {
 		axis = ptr->data;
 		ptr = ptr->next; /* list may change under us */
-		if (IS_GOG_AXIS (axis)) {
+		if (GOG_IS_AXIS (axis)) {
 			type = -1;
 			g_object_get (G_OBJECT (axis), "type", &type, NULL);
 			if (type < 0 || type >= GOG_AXIS_TYPES) {
@@ -735,11 +798,11 @@ gog_chart_get_axes (GogChart const *chart, GogAxisType target)
 	GogAxis *axis;
 	int type;
 
-	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	g_return_val_if_fail (GOG_IS_CHART (chart), NULL);
 
 	for (ptr = GOG_OBJECT (chart)->children ; ptr != NULL ; ptr = ptr->next) {
 		axis = ptr->data;
-		if (IS_GOG_AXIS (axis)) {
+		if (GOG_IS_AXIS (axis)) {
 			type = -1;
 			g_object_get (G_OBJECT (axis), "type", &type, NULL);
 			if (type < 0 || type >= GOG_AXIS_TYPES) {
@@ -764,7 +827,7 @@ gog_chart_get_axes (GogChart const *chart, GogAxisType target)
 GogGrid  *
 gog_chart_get_grid (GogChart const *chart)
 {
-	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	g_return_val_if_fail (GOG_IS_CHART (chart), NULL);
 	return GOG_GRID (chart->grid);
 }
 
@@ -774,8 +837,10 @@ gog_chart_is_3d (GogChart const *chart)
 	return chart->axis_set == GOG_AXIS_SET_XYZ;
 }
 
+/*********************************************************************/
+
 static void
-gog_chart_3d_process (GogChart *chart, GogViewAllocation const *bbox)
+gog_chart_view_3d_process (GogView *view, GogViewAllocation *bbox)
 {
 	/* A XYZ axis set in supposed. If new sets (cylindrical, spherical or
 	other are added, we'll need to change this code */
@@ -785,7 +850,11 @@ gog_chart_3d_process (GogChart *chart, GogViewAllocation const *bbox)
 	double xmin, xmax, ymin, ymax, zmin, zmax;
 	double o[3], x[3], y[3], z[3], tg, d;
 	Gog3DBox *box;
+	GogChart *chart = GOG_CHART (gog_view_get_model (view));
 	GogObject *obj = gog_object_get_child_by_name (GOG_OBJECT (chart), "3D-Box");
+	GSList *ptr;
+	GogView *child;
+	GogViewPadding padding;
 
 	if (!obj) {
 		obj = g_object_new (GOG_3D_BOX_TYPE, NULL);
@@ -857,24 +926,24 @@ gog_chart_3d_process (GogChart *chart, GogViewAllocation const *bbox)
 		if (d < box->r)
 			box->r = d;
 		/* also calculate the reduction factor we need to make things fit in the bbox */
-		xmax = fabs (o[0]) * (1. + o[1] / box->r);
-		zmax = fabs (o[2]) * (1. + o[1] / box->r);
-		d = fabs (x[0]) * (1. + x[1] / box->r);
+		xmax = fabs (o[0]) / (1. - o[1] / box->r);
+		zmax = fabs (o[2]) / (1. - o[1] / box->r);
+		d = fabs (x[0]) / (1. - x[1] / box->r);
 		if (d > xmax)
 			xmax = d;
-		d = fabs (x[2]) * (1. + x[1] / box->r);
+		d = fabs (x[2]) / (1. - x[1] / box->r);
 		if (d > zmax)
 			zmax = d;
-		d = fabs (y[0]) * (1. + y[1] / box->r);
+		d = fabs (y[0]) / (1. - y[1] / box->r);
 		if (d > xmax)
 			xmax = d;
-		d = fabs (y[2]) * (1. + y[1] / box->r);
+		d = fabs (y[2]) / (1. - y[1] / box->r);
 		if (d > zmax)
 			zmax = d;
-		d = fabs (z[0]) * (1. + z[1] / box->r);
+		d = fabs (z[0]) / (1. - z[1] / box->r);
 		if (d > xmax)
 			xmax = d;
-		d = fabs (z[2]) * (1. + z[1] / box->r);
+		d = fabs (z[2]) / (1. - z[1] / box->r);
 		if (d > zmax)
 			zmax = d;
 	} else {
@@ -904,9 +973,40 @@ gog_chart_3d_process (GogChart *chart, GogViewAllocation const *bbox)
 	d = xmax / tmp.w;
 	tg = zmax / tmp.h;
 	box->ratio = (d > tg)? d: tg;
-}
 
-/*********************************************************************/
+	gog_view_padding_request (view, bbox, &padding);
+	
+	if (!chart->is_plot_area_manual) {
+		bbox->x += padding.wl;
+		bbox->w -= padding.wl + padding.wr;
+		bbox->y += padding.ht;
+		bbox->h -= padding.ht + padding.hb;
+	} else {
+		tmp.x -= padding.wl;
+		tmp.w += padding.wl + padding.wr;
+		tmp.y -= padding.ht;
+		tmp.h += padding.ht + padding.hb;
+	}
+
+	/* Recalculating ratio */
+	d = xmax / bbox->w;
+	tg = zmax / bbox->h;
+	box->ratio = (d > tg)? d: tg;
+
+	for (ptr = view->children; ptr != NULL ; ptr = ptr->next) {
+		child = ptr->data;
+		if (GOG_POSITION_IS_PADDING (child->model->position)) {
+			gog_view_size_allocate (child, &tmp);
+		}
+	}
+
+	/* by default, overlay all GOG_POSITION_SPECIAL children in residual */
+	for (ptr = view->children; ptr != NULL ; ptr = ptr->next) {
+		child = ptr->data;
+		if (GOG_POSITION_IS_SPECIAL (child->model->position))
+			gog_view_size_allocate (child, bbox);
+	}
+}
 
 typedef struct {
 	GogOutlinedView base;
@@ -915,9 +1015,9 @@ typedef struct {
 } GogChartView;
 typedef GogOutlinedViewClass	GogChartViewClass;
 
-#define GOG_CHART_VIEW_TYPE	(gog_chart_view_get_type ())
-#define GOG_CHART_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_CHART_VIEW_TYPE, GogChartView))
-#define IS_GOG_CHART_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_CHART_VIEW_TYPE))
+#define GOG_TYPE_CHART_VIEW	(gog_chart_view_get_type ())
+#define GOG_CHART_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_CHART_VIEW, GogChartView))
+#define GOG_IS_CHART_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_CHART_VIEW))
 
 static GogViewClass *cview_parent_klass;
 
@@ -941,6 +1041,12 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 	} else
 		*plot_area = view->residual;
 
+	/* special treatment for 3d charts */
+	if (gog_chart_is_3d (chart)) {
+		gog_chart_view_3d_process (view, plot_area);
+		return;
+	}
+
 	tmp = *plot_area;
 	gog_view_padding_request (view, plot_area, &padding);
 	
@@ -969,10 +1075,6 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 		if (GOG_POSITION_IS_SPECIAL (child->model->position))
 			gog_view_size_allocate (child, plot_area);
 	}
-
-	/* special treatment for 3d charts */
-	if (gog_chart_is_3d (chart))
-	    gog_chart_3d_process (chart, plot_area);
 }
 
 static void
@@ -990,10 +1092,10 @@ grid_line_render (GSList *start_ptr, GogViewAllocation const *bbox)
 
 	for (ptr = start_ptr; ptr != NULL; ptr = ptr->next) {
 		child_view = ptr->data;
-		if (IS_GOG_AXIS (child_view->model)) {
+		if (GOG_IS_AXIS (child_view->model)) {
 			for (child_ptr = child_view->children; child_ptr != NULL; child_ptr = child_ptr->next) {
 				axis_child_view = child_ptr->data;
-				if (IS_GOG_GRID_LINE (axis_child_view->model)) {
+				if (GOG_IS_GRID_LINE (axis_child_view->model)) {
 					if (gog_grid_line_is_minor (GOG_GRID_LINE (axis_child_view->model)))
 						minor_grid_lines = g_slist_prepend (minor_grid_lines, 
 										    axis_child_view);
@@ -1034,7 +1136,7 @@ plot_render (GogView *view, GogViewAllocation const *bbox)
 	/* Render some plots before axes */
 	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
 		child_view = ptr->data;
-		if (IS_GOG_PLOT (child_view->model) && 
+		if (GOG_IS_PLOT (child_view->model) && 
 		    GOG_PLOT (child_view->model)->render_before_axes)
 			gog_view_render	(ptr->data, bbox);
 	}
@@ -1053,25 +1155,34 @@ gog_chart_view_render (GogView *view, GogViewAllocation const *bbox)
 	if (gog_chart_is_3d (chart)) {
 		for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
 			child_view = ptr->data;
-			if (!IS_GOG_AXIS (child_view->model) && !IS_GOG_PLOT (child_view->model)) 
-			    gog_view_render	(ptr->data, bbox);
+			if (!GOG_IS_AXIS (child_view->model) && !GOG_IS_PLOT (child_view->model)) 
+				gog_view_render	(ptr->data, bbox);
 		}
 		/* now render plot and axes */
 		for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
 			child_view = ptr->data;
-			if (IS_GOG_PLOT (child_view->model)) 
-			    gog_view_render	(ptr->data, bbox);
+			if (!GOG_IS_AXIS (child_view->model))
+				continue;
+			gog_view_render (ptr->data, bbox);
+			grid_line_render (ptr, bbox);
+		}
+		for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
+			child_view = ptr->data;
+			if (GOG_IS_AXIS (child_view->model))
+				continue;
+			if (GOG_IS_PLOT (child_view->model)) 
+				gog_view_render	(ptr->data, bbox);
 		}
 	} else {
 		/* KLUDGE: render grid lines before axis */
 		for (ptr = view->children ; ptr != NULL ; ptr = ptr->next) {
 			child_view = ptr->data;
-			if (!grid_line_rendered && IS_GOG_AXIS (child_view->model)) {
+			if (!grid_line_rendered && GOG_IS_AXIS (child_view->model)) {
 				grid_line_render (ptr, bbox);
 				plot_render (view, bbox);
 				grid_line_rendered = TRUE;
 			}
-			if (IS_GOG_PLOT (child_view->model)) {
+			if (GOG_IS_PLOT (child_view->model)) {
 			    if (!GOG_PLOT (child_view->model)->render_before_axes)
 				gog_view_render	(ptr->data, bbox);
 			} else
@@ -1096,12 +1207,12 @@ gog_chart_view_class_init (GogChartViewClass *gview_klass)
 
 static GSF_CLASS (GogChartView, gog_chart_view,
 		  gog_chart_view_class_init, gog_chart_view_init,
-		  GOG_OUTLINED_VIEW_TYPE)
+		  GOG_TYPE_OUTLINED_VIEW)
 
 GogViewAllocation const *
 gog_chart_view_get_plot_area (GogView const *view)
 {
-	g_return_val_if_fail (IS_GOG_CHART_VIEW (view), NULL);
+	g_return_val_if_fail (GOG_IS_CHART_VIEW (view), NULL);
 
 	return &(GOG_CHART_VIEW (view)->plot_area);
 }
