@@ -9,13 +9,7 @@
  *   Almer S. Tigelaar (almer@gnome.org)
  */
 #include <goffice/goffice-config.h>
-#include "go-font-sel.h"
-#include <goffice/utils/go-font.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/utils/go-color.h>
-
-#include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
-#include <goffice/cut-n-paste/foocanvas/foo-canvas-text.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -35,8 +29,8 @@ struct _GOFontSel {
 	GtkTreeView	*font_style_list;
 	GtkTreeView	*font_size_list;
 
-	FooCanvas	*font_preview_canvas;
-	FooCanvasItem	*font_preview_text;
+	GocCanvas	*font_preview_canvas;
+	GocItem		*font_preview_text;
 
 	GOFont		*base, *current;
 	PangoAttrList	*modifications;
@@ -77,7 +71,7 @@ go_font_sel_emit_changed (GOFontSel *gfs)
 {
 	g_signal_emit (G_OBJECT (gfs),
 		gfs_signals [FONT_CHANGED], 0, gfs->modifications);
-	foo_canvas_item_set (gfs->font_preview_text,
+	goc_item_set (gfs->font_preview_text,
 		"attributes",  gfs->modifications,
 		NULL);
 }
@@ -329,13 +323,10 @@ canvas_size_changed (G_GNUC_UNUSED GtkWidget *widget,
 	int width  = allocation->width - 1;
 	int height = allocation->height - 1;
 
-	foo_canvas_item_set (gfs->font_preview_text,
+	goc_item_set (gfs->font_preview_text,
 		"x", (double)width/2.,
 		"y", (double)height/2.,
 		NULL);
-
-	foo_canvas_set_scroll_region (gfs->font_preview_canvas, 0, 0,
-				      width, height);
 }
 
 static void
@@ -343,7 +334,7 @@ gfs_init (GOFontSel *gfs)
 {
 	GtkWidget *w;
 
-	gfs->gui = go_libglade_new ("go-font-sel.glade", "toplevel-table", GETTEXT_PACKAGE, NULL);
+	gfs->gui = go_glade_new ("go-font-sel.glade", "toplevel-table", GETTEXT_PACKAGE, NULL);
 	if (gfs->gui == NULL)
                 return;
 
@@ -359,18 +350,16 @@ gfs_init (GOFontSel *gfs)
 	gfs->font_style_list = GTK_TREE_VIEW (glade_xml_get_widget (gfs->gui, "font-style-list"));
 	gfs->font_size_list  = GTK_TREE_VIEW (glade_xml_get_widget (gfs->gui, "font-size-list"));
 
-	w = foo_canvas_new ();
-	gfs->font_preview_canvas = FOO_CANVAS (w);
-	foo_canvas_set_scroll_region (gfs->font_preview_canvas, -1, -1, INT_MAX/2, INT_MAX/2);
-	foo_canvas_scroll_to (gfs->font_preview_canvas, 0, 0);
+	w = GTK_WIDGET (g_object_new (GOC_TYPE_CANVAS, NULL));
+	gfs->font_preview_canvas = GOC_CANVAS (w);
 	gtk_widget_show_all (w);
 	w = glade_xml_get_widget (gfs->gui, "font-preview-frame");
 	gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (gfs->font_preview_canvas));
 
-	gfs->font_preview_text = FOO_CANVAS_ITEM (foo_canvas_item_new (
-		foo_canvas_root (gfs->font_preview_canvas),
-		FOO_TYPE_CANVAS_TEXT,
-		NULL));
+	gfs->font_preview_text = goc_item_new (
+		goc_canvas_get_root (gfs->font_preview_canvas),
+		GOC_TYPE_TEXT,
+		NULL);
 	go_font_sel_set_sample_text (gfs, NULL); /* init to default */
 
 	g_signal_connect (G_OBJECT (gfs->font_preview_canvas),
@@ -441,7 +430,7 @@ GSF_CLASS (GOFontSel, go_font_sel,
 GtkWidget *
 go_font_sel_new (void)
 {
-	return g_object_new (GO_FONT_SEL_TYPE, NULL);
+	return g_object_new (GO_TYPE_FONT_SEL, NULL);
 }
 
 void
@@ -458,8 +447,8 @@ go_font_sel_editable_enters (GOFontSel *gfs, GtkWindow *dialog)
 void
 go_font_sel_set_sample_text (GOFontSel *gfs, char const *text)
 {
-	g_return_if_fail (IS_GO_FONT_SEL (gfs));
-	foo_canvas_item_set (gfs->font_preview_text,
+	g_return_if_fail (GO_IS_FONT_SEL (gfs));
+	goc_item_set (gfs->font_preview_text,
 		/* xgettext: This text is used as a sample when selecting a font
 		 * please choose a translation that would produce common
 		 * characters specific to the target alphabet. */
@@ -470,7 +459,7 @@ go_font_sel_set_sample_text (GOFontSel *gfs, char const *text)
 GOFont const *
 go_font_sel_get_font (GOFontSel const *gfs)
 {
-	g_return_val_if_fail (IS_GO_FONT_SEL (gfs), NULL);
+	g_return_val_if_fail (GO_IS_FONT_SEL (gfs), NULL);
 	return gfs->current;
 }
 
@@ -540,7 +529,7 @@ go_font_sel_set_color (GOFontSel *gfs, GOColor c)
 void
 go_font_sel_set_font (GOFontSel *gfs, GOFont const *font)
 {
-	g_return_if_fail (IS_GO_FONT_SEL (gfs));
+	g_return_if_fail (GO_IS_FONT_SEL (gfs));
 
 	go_font_sel_set_name (gfs, pango_font_description_get_family (font->desc));
 	go_font_sel_set_style (gfs,
