@@ -22,13 +22,7 @@
 #define GO_FORMAT_H
 
 #include <goffice/goffice.h>
-#include <goffice/goffice-features.h>
-#include <goffice/utils/goffice-utils.h>
-#include <pango/pango-attributes.h>
-#include <pango/pango-layout.h>
-#include <glib.h>
-
-#include <glib-object.h>
+#include <gsf/gsf-libxml.h>
 
 G_BEGIN_DECLS
 
@@ -68,6 +62,40 @@ typedef enum {
 	GO_FORMAT_NUMBER_DATE_ERROR
 } GOFormatNumberError;
 
+typedef struct {
+	gchar const *symbol;
+	gchar const *description;
+	gboolean precedes;
+	gboolean has_space;
+} GOFormatCurrency;
+
+typedef struct {
+	GOFormatFamily family;
+	GOFormatMagic magic;
+
+	/* NUMBER, SCIENTIFIC, CURRENCY, ACCOUNTING, PERCENTAGE: */
+	int min_digits;
+	int num_decimals;
+
+	/* NUMBER, CURRENCY, ACCOUNTING, PERCENTAGE: */
+	gboolean thousands_sep;
+
+	/* NUMBER, CURRENCY, ACCOUNTING, PERCENTAGE: */
+	gboolean negative_red;
+	gboolean negative_paren;
+
+	/* CURRENCY, ACCOUNTING: */
+	GOFormatCurrency const *currency;
+
+	/* CURRENCY: */
+	gboolean force_quoted;
+
+	/* SCIENTIFIC: */
+	int exponent_step;
+	gboolean use_markup;
+	gboolean simplify_mantissa;
+} GOFormatDetails;
+
 /*************************************************************************/
 
 typedef int (*GOFormatMeasure) (const GString *str, PangoLayout *layout);
@@ -105,6 +133,19 @@ GOFormat *go_format_default_percentage	(void);
 GOFormat *go_format_default_money	(void);
 GOFormat *go_format_default_accounting  (void);
 
+void      go_format_generate_number_str (GString *dst,
+					 int min_digits,
+					 int num_decimals,
+					 gboolean thousands_sep,
+					 gboolean negative_red,
+					 gboolean negative_paren,
+					 const char *prefix,
+					 const char *postfix);
+void  go_format_details_init            (GOFormatDetails *details,
+					 GOFormatFamily family);
+void  go_format_generate_str            (GString *dst,
+					 GOFormatDetails const *details);
+
 char     *go_format_str_localize        (char const *str);
 char	 *go_format_str_delocalize	(char const *str);
 const char* go_format_as_XL	   	(GOFormat const *fmt);
@@ -138,6 +179,10 @@ const GOFormat *go_format_specializel         (GOFormat const *fmt,
 
 GOFormatFamily         go_format_get_family (GOFormat const *fmt);
 
+void      go_format_get_details         (GOFormat const *fmt,
+					 GOFormatDetails *dst,
+					 gboolean *exact);
+
 const PangoAttrList *go_format_get_markup (GOFormat const *fmt);
 
 gboolean go_format_is_simple (GOFormat const *fmt);
@@ -172,17 +217,22 @@ GOFormat *go_format_inc_precision	(GOFormat const *fmt);
 GOFormat *go_format_dec_precision	(GOFormat const *fmt);
 GOFormat *go_format_toggle_1000sep	(GOFormat const *fmt);
 
-typedef struct {
-	gchar const *symbol;
-	gchar const *description;
-	gboolean precedes;
-	gboolean has_space;
-} GOFormatCurrency;
+/******************* GOFormat ODF Support ********************************/
+
+char *go_format_odf_style_map (GOFormat const *fmt, int cond_part);
+gboolean go_format_output_to_odf (GsfXMLOut *xout, GOFormat const *fmt, 
+				  int cond_part, char const *name,
+				  gboolean with_extension);
+
+
+/*************************************************************************/
 
 /* Indexed by GOFormatFamily */
 GO_VAR_DECL char const * const * const go_format_builtins [];
 GO_VAR_DECL GOFormatCurrency     const go_format_currencies [];
 
+GOFormatCurrency const *go_format_locale_currency (void);
+
 /*************************************************************************/
 
 void go_number_format_init (void);
