@@ -35,9 +35,9 @@
 #include <math.h>
 #include <string.h>
 
-#define GOG_PROBABILITY_PLOT_SERIES_TYPE	(gog_probability_plot_series_get_type ())
-#define GOG_PROBABILITY_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_PROBABILITY_PLOT_SERIES_TYPE, GogProbabilityPlotSeries))
-#define IS_GOG_PROBABILITY_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_PROBABILITY_PLOT_SERIES_TYPE))
+#define GOG_TYPE_PROBABILITY_PLOT_SERIES	(gog_probability_plot_series_get_type ())
+#define GOG_PROBABILITY_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_PROBABILITY_PLOT_SERIES, GogProbabilityPlotSeries))
+#define GOG_IS_PROBABILITY_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_PROBABILITY_PLOT_SERIES))
 
 typedef struct {
 	GogSeries base;
@@ -55,11 +55,11 @@ static GogObjectClass *probability_plot_parent_klass;
 #ifdef GOFFICE_WITH_GTK
 static void
 gog_probability_plot_populate_editor (GogObject *item,
-			      GogEditor *editor,
+			      GOEditor *editor,
 			      GogDataAllocator *dalloc,
 			      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor, go_distribution_pref_new (G_OBJECT (item), dalloc, cc), _("Distribution"));
+	go_editor_add_page (editor, go_distribution_pref_new (G_OBJECT (item), dalloc, cc), _("Distribution"));
 	
 	(GOG_OBJECT_CLASS(probability_plot_parent_klass)->populate_editor) (item, editor, dalloc, cc);
 }
@@ -237,7 +237,7 @@ gog_probability_plot_class_init (GogPlotClass *gog_plot_klass)
 		g_param_spec_object ("distribution", 
 			_("Distribution"),
 			_("A pointer to the GODistribution used by this plot"),
-			GO_DISTRIBUTION_TYPE, 
+			GO_TYPE_DISTRIBUTION, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PROBABILITY_PLOT_PROP_SHAPE_PARAM1,
 		g_param_spec_string ("param1", 
@@ -267,7 +267,7 @@ gog_probability_plot_class_init (GogPlotClass *gog_plot_klass)
 	plot_klass->desc.num_series_max = 1;
 	plot_klass->series_type = gog_probability_plot_series_get_type ();
 	plot_klass->axis_set = GOG_AXIS_SET_XY;
-	plot_klass->desc.series.style_fields	= GOG_STYLE_MARKER;
+	plot_klass->desc.series.style_fields	= GO_STYLE_MARKER;
 	plot_klass->axis_get_bounds   		= gog_probability_plot_axis_get_bounds;
 #ifdef GOFFICE_WITH_GTK
 	gog_object_klass->populate_editor = gog_probability_plot_populate_editor;
@@ -314,7 +314,7 @@ gog_probability_plot_dataset_dim_changed (GogDataset *set, int dim_i)
 		GValue value = {0};
 		g_value_init (&value, G_TYPE_DOUBLE);
 		if (plot->shape_params[dim_i].elem->data)
-			g_value_set_double (&value, go_data_scalar_get_value (GO_DATA_SCALAR (plot->shape_params[dim_i].elem->data)));
+			g_value_set_double (&value, go_data_get_scalar_value (plot->shape_params[dim_i].elem->data));
 		else
 			g_param_value_set_default (spec, &value);
 		g_param_value_validate (spec, &value);
@@ -341,8 +341,8 @@ gog_probability_plot_dataset_init (GogDatasetClass *iface)
 
 GSF_DYNAMIC_CLASS_FULL (GogProbabilityPlot, gog_probability_plot,
 	NULL, NULL, gog_probability_plot_class_init, NULL,
-	gog_probability_plot_init, GOG_PLOT_TYPE, 0,
-	GSF_INTERFACE (gog_probability_plot_dataset_init, GOG_DATASET_TYPE))
+	gog_probability_plot_init, GOG_TYPE_PLOT, 0,
+	GSF_INTERFACE (gog_probability_plot_dataset_init, GOG_TYPE_DATASET))
 
 /************************************************,*****************************/
 typedef GogPlotView		GogProbabilityPlotView;
@@ -358,10 +358,15 @@ gog_probability_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogViewAllocation const *area;
 	GogProbabilityPlotSeries const *series;
 	unsigned i, nb;
-	GogStyle *style;
+	GOStyle *style;
+	GSList *ptr;
 
 	if (model->base.series == NULL)
 		return;
+
+	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next)
+		gog_view_render	(ptr->data, bbox);
+
 	series = GOG_PROBABILITY_PLOT_SERIES (model->base.series->data);
 	nb = series->base.num_elements;
 	style = GOG_STYLED_OBJECT (series)->style;
@@ -392,18 +397,88 @@ gog_probability_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 
 static GogViewClass *probability_plot_view_parent_klass;
 
+static void
+gog_probability_plot_view_size_allocate (GogView *view, GogViewAllocation const *allocation)
+{
+	GSList *ptr;
+	for (ptr = view->children; ptr != NULL; ptr = ptr->next)
+		gog_view_size_allocate (GOG_VIEW (ptr->data), allocation);
+	(probability_plot_view_parent_klass->size_allocate) (view, allocation);
+}
+
 static void
 gog_probability_plot_view_class_init (GogViewClass *view_klass)
 {
 	probability_plot_view_parent_klass = (GogViewClass*) g_type_class_peek_parent (view_klass);
 	view_klass->render	  = gog_probability_plot_view_render;
+	view_klass->size_allocate = gog_probability_plot_view_size_allocate;
 	view_klass->clip	  = FALSE;
 }
 
 GSF_DYNAMIC_CLASS (GogProbabilityPlotView, gog_probability_plot_view,
 	gog_probability_plot_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
+
+/*****************************************************************************/
+
+static gboolean
+regression_curve_can_add (GogObject const *parent)
+{
+	return (gog_object_get_child_by_name (parent, "Regression line") == NULL);
+}
+
+static void
+regression_curve_post_add (GogObject *parent, GogObject *child)
+{
+	gog_object_request_update (child);
+}
+
+static void
+regression_curve_pre_remove (GogObject *parent, GogObject *child)
+{
+}
+
+/*****************************************************************************/
+
+typedef GogView		GogProbabilityPlotSeriesView;
+typedef GogViewClass	GogProbabilityPlotSeriesViewClass;
+
+#define GOG_TYPE_PROBABILITY_SERIES_VIEW	(gog_probability_plot_series_view_get_type ())
+#define GOG__PROBABILITY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE__PROBABILITY_SERIES_VIEW, GogProbabilityPlotSeriesView))
+#define GOG_IS__PROBABILITY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE__PROBABILITY_SERIES_VIEW))
+
+GType gog_probability_plot_series_view_get_type (void);
+
+static void
+gog_probability_plot_series_view_render (GogView *view, GogViewAllocation const *bbox)
+{
+	GSList *ptr;
+	for (ptr = view->children ; ptr != NULL ; ptr = ptr->next)
+		gog_view_render	(ptr->data, bbox);
+}
+
+static void
+gog_probability_plot_series_view_size_allocate (GogView *view, GogViewAllocation const *allocation)
+{
+	GSList *ptr;
+
+	for (ptr = view->children; ptr != NULL; ptr = ptr->next)
+		gog_view_size_allocate (GOG_VIEW (ptr->data), allocation);
+}
+
+static void
+gog_probability_plot_series_view_class_init (GogProbabilityPlotSeriesViewClass *gview_klass)
+{
+	GogViewClass *view_klass = GOG_VIEW_CLASS (gview_klass);
+	view_klass->render = gog_probability_plot_series_view_render;
+	view_klass->size_allocate = gog_probability_plot_series_view_size_allocate;
+	view_klass->build_toolkit = NULL;
+}
+
+GSF_DYNAMIC_CLASS (GogProbabilityPlotSeriesView, gog_probability_plot_series_view,
+	gog_probability_plot_series_view_class_init, NULL,
+	GOG_TYPE_VIEW)
 /****************************************************************************/
 
 static GogObjectClass *gog_probability_plot_series_parent_klass;
@@ -418,13 +493,13 @@ gog_probability_plot_series_update (GogObject *obj)
 	double mn, d;
 	unsigned i;
 	GODistribution *dist = GO_DISTRIBUTION (((GogProbabilityPlot *) series->base.plot)->dist);
+	GSList *ptr;
 
 	g_free (series->x);
 	series->x = NULL;
 	if (series->base.values[0].data != NULL) {
-		x_vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[0].data));
-		series->base.num_elements = go_data_vector_get_len 
-			(GO_DATA_VECTOR (series->base.values[0].data));
+		x_vals = go_data_get_values (series->base.values[0].data);
+		series->base.num_elements = go_data_get_vector_size (series->base.values[0].data);
 		if (x_vals)
 			series->x = go_range_sort (x_vals, series->base.num_elements);
 	}
@@ -439,10 +514,15 @@ gog_probability_plot_series_update (GogObject *obj)
 				series->y[i] = go_distribution_get_ppf (dist, (i + .6825) / d);
 			series->y[i] = go_distribution_get_ppf (dist, mn);
 		}
-			
+
 	} else
 		series->y = NULL;
 
+	/* update children */
+	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
+		if (!GOG_IS_SERIES_LINES (ptr->data))
+			gog_object_request_update (GOG_OBJECT (ptr->data));
+
 	/* queue plot for redraw */
 	gog_object_request_update (GOG_OBJECT (series->base.plot));
 
@@ -450,6 +530,17 @@ gog_probability_plot_series_update (GogObject *obj)
 		gog_probability_plot_series_parent_klass->update (obj);
 }
 
+static unsigned
+gog_probability_plot_series_get_xy_data (GogSeries const  *series,
+			double const 	**x, 
+			double const 	**y)
+{
+	GogProbabilityPlotSeries *ppseries = GOG_PROBABILITY_PLOT_SERIES (series);
+	*x = ppseries->x;
+	*y = ppseries->y;
+	return series->num_elements;
+}
+
 static void
 gog_probability_plot_series_finalize (GObject *obj)
 {
@@ -466,16 +557,31 @@ gog_probability_plot_series_finalize (GObject *obj)
 static void
 gog_probability_plot_series_class_init (GogObjectClass *obj_klass)
 {
-	GogStyledObjectClass *gso_klass = (GogStyledObjectClass*) obj_klass;
-	GObjectClass *gobject_klass = (GObjectClass *) gso_klass;
+	GObjectClass *gobject_klass = (GObjectClass *) obj_klass;
+	GogSeriesClass *series_klass = (GogSeriesClass *) obj_klass;
+
+	static GogObjectRole const roles[] = {
+		{ N_("Regression line"), "GogLinRegCurve",	0,
+		  GOG_POSITION_SPECIAL, GOG_POSITION_SPECIAL, GOG_OBJECT_NAME_BY_ROLE,
+		  regression_curve_can_add,
+		  NULL,
+		  NULL,
+		  regression_curve_post_add,
+		  regression_curve_pre_remove,
+		  NULL }
+	};
 
 	series_parent_klass = g_type_class_peek_parent (obj_klass);
 	gobject_klass->finalize		= gog_probability_plot_series_finalize;
 
 	gog_probability_plot_series_parent_klass = g_type_class_peek_parent (obj_klass);
 	obj_klass->update = gog_probability_plot_series_update;
+	obj_klass->view_type	= gog_probability_plot_series_view_get_type ();
+	gog_object_register_roles (obj_klass, roles, G_N_ELEMENTS (roles));
+
+	series_klass->get_xy_data = gog_probability_plot_series_get_xy_data;
 }
 
 GSF_DYNAMIC_CLASS (GogProbabilityPlotSeries, gog_probability_plot_series,
 	gog_probability_plot_series_class_init, NULL,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
