@@ -26,6 +26,7 @@
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/math/go-math.h>
 #include <goffice/math/go-rangefunc.h>
+#include <goffice/utils/go-persist.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
@@ -48,7 +49,7 @@ steps_changed_cb (GtkSpinButton *button, GObject *es)
 
 static void
 gog_exp_smooth_populate_editor (GogObject *obj, 
-				GogEditor *editor,
+				GOEditor *editor,
 				GogDataAllocator *dalloc,
 				GOCmdContext *cc)
 {
@@ -57,7 +58,7 @@ gog_exp_smooth_populate_editor (GogObject *obj,
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_smoothing"));
 	char	 *path = g_build_filename (dir, "gog-exp-smooth.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "exp-smooth-prefs", GETTEXT_PACKAGE, cc);
+	GladeXML *gui = go_glade_new (path, "exp-smooth-prefs", GETTEXT_PACKAGE, cc);
 	GtkWidget *label, *box, *w = glade_xml_get_widget (gui, "steps");
 	GtkTable *table;
 
@@ -78,7 +79,7 @@ gog_exp_smooth_populate_editor (GogObject *obj,
 	g_object_set (G_OBJECT (label), "mnemonic-widget", w, NULL);
 	g_object_set_data_full (G_OBJECT (table),
 		"state", gui, (GDestroyNotify) g_object_unref);
-	gog_editor_add_page (editor, table, _("Properties"));
+	go_editor_add_page (editor, table, _("Properties"));
 
 	(GOG_OBJECT_CLASS (exp_smooth_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 }
@@ -124,8 +125,7 @@ gog_exp_smooth_update (GogObject *obj)
 	go_range_min (x, n, &xmin);
 	go_range_max (x, n, &xmax);
 	if (es->period->data != NULL)
-		period = go_data_scalar_get_value (
-			GO_DATA_SCALAR (es->period->data));
+		period = go_data_get_scalar_value (es->period->data);
 	if (period <= 0.)
 		period = 10. * (xmax - xmin) / (n - 1);
 
@@ -140,7 +140,7 @@ gog_exp_smooth_update (GogObject *obj)
 		nb = (unsigned) ceil ((x[i] - xmin) / delta - epsilon);
 		t = pow (2., (x[i] - xmin - nb * delta) / period);
 		incr[nb] += t * y[i];
-		w[nb] += t;		
+		w[nb] += t;
 	}
 	r = pow (2., -delta / period);
 	t = u = 0.;
@@ -232,7 +232,7 @@ gog_exp_smooth_class_init (GogSmoothedCurveClass *curve_klass)
 			_("Steps"),
 			_("Number of interpolation steps"), 
 			10, G_MAXINT, 100,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 static void
@@ -273,5 +273,5 @@ gog_exp_smooth_dataset_init (GogDatasetClass *iface)
 
 GSF_DYNAMIC_CLASS_FULL (GogExpSmooth, gog_exp_smooth,
 	 NULL, NULL, gog_exp_smooth_class_init, NULL,
-	gog_exp_smooth_init, GOG_SMOOTHED_CURVE_TYPE, 0,
-	GSF_INTERFACE (gog_exp_smooth_dataset_init, GOG_DATASET_TYPE))
+	gog_exp_smooth_init, GOG_TYPE_SMOOTHED_CURVE, 0,
+	GSF_INTERFACE (gog_exp_smooth_dataset_init, GOG_TYPE_DATASET))
